aboutsummaryrefslogtreecommitdiffstatshomepage
path: root/lib/plugins/styling/action.php
diff options
context:
space:
mode:
Diffstat (limited to 'lib/plugins/styling/action.php')
-rw-r--r--lib/plugins/styling/action.php25
1 files changed, 15 insertions, 10 deletions
diff --git a/lib/plugins/styling/action.php b/lib/plugins/styling/action.php
index 46245ca75..39da86028 100644
--- a/lib/plugins/styling/action.php
+++ b/lib/plugins/styling/action.php
@@ -1,20 +1,24 @@
<?php
+
+use dokuwiki\Extension\ActionPlugin;
+use dokuwiki\Extension\EventHandler;
+use dokuwiki\Extension\Event;
+
/**
* DokuWiki Plugin styling (Action Component)
*
* @license GPL 2 http://www.gnu.org/licenses/gpl-2.0.html
* @author Andreas Gohr <andi@splitbrain.org>
*/
-class action_plugin_styling extends DokuWiki_Action_Plugin
+class action_plugin_styling extends ActionPlugin
{
-
/**
* Registers a callback functions
*
* @param Doku_Event_Handler $controller DokuWiki's event controller object
* @return void
*/
- public function register(Doku_Event_Handler $controller)
+ public function register(EventHandler $controller)
{
$controller->register_hook('TPL_METAHEADER_OUTPUT', 'BEFORE', $this, 'handleHeader');
}
@@ -22,12 +26,12 @@ class action_plugin_styling extends DokuWiki_Action_Plugin
/**
* Adds the preview parameter to the stylesheet loading in non-js mode
*
- * @param Doku_Event $event event object by reference
- * @param mixed $param [the parameters passed as fifth argument to register_hook() when this
- * handler was registered]
+ * @param Event $event event object by reference
+ * @param mixed $param [the parameters passed as fifth argument to register_hook() when this
+ * handler was registered]
* @return void
*/
- public function handleHeader(Doku_Event &$event, $param)
+ public function handleHeader(Event &$event, $param)
{
global $ACT;
global $INPUT;
@@ -39,10 +43,11 @@ class action_plugin_styling extends DokuWiki_Action_Plugin
// set preview
$len = count($event->data['link']);
for ($i = 0; $i < $len; $i++) {
- if ($event->data['link'][$i]['rel'] == 'stylesheet' &&
+ if (
+ $event->data['link'][$i]['rel'] == 'stylesheet' &&
strpos($event->data['link'][$i]['href'], 'lib/exe/css.php') !== false
) {
- $event->data['link'][$i]['href'] .= '&preview=1&tseed='.time();
+ $event->data['link'][$i]['href'] .= '&preview=1&tseed=' . time();
}
}
}
@@ -1,20 +1,24 @@
* Registers a callback functions
*
- * @param Doku_Event_Handler $controller DokuWiki's event controller object
+ * @param EventHandler $controller DokuWiki's event controller object
* @return void
*/